@@ -19,14 +19,14 @@
 #include "k3bglobals.h"
 #include "k3bprocess.h"
 
-#include <QDir>
-#include <QFile>
-#include <QFileInfo>
-#include <QStringList>
-#include <QTextStream>
+#include <KCoreAddons/KProcess>
 
-#include <KDebug>
-#include <KProcess>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QStringList>
+#include <QtCore/QTextStream>
 
 
 void K3b::addDefaultPrograms( K3b::ExternalBinManager* m )
@@ -37,12 +37,15 @@ void K3b::addDefaultPrograms( K3b::ExternalBinManager* m )
     m->addProgram( new K3b::CdrdaoProgram() );
     m->addProgram( new K3b::GrowisofsProgram() );
     m->addProgram( new K3b::DvdformatProgram() );
+    m->addProgram(new K3b::CdrskinProgram());
     //  m->addProgram( new K3b::DvdBooktypeProgram() );
 }
 
 
 void K3b::addTranscodePrograms( K3b::ExternalBinManager* m )
 {
+    Q_UNUSED(m);
+    /* Deprecated transcode
     static const char* const transcodeTools[] =  { "transcode",
                                              0, // K3b 1.0 only uses the transcode binary
                                              "tcprobe",
@@ -54,6 +57,7 @@ void K3b::addTranscodePrograms( K3b::ExternalBinManager* m )
 
     for( int i = 0; transcodeTools[i]; ++i )
         m->addProgram( new K3b::TranscodeProgram( transcodeTools[i] ) );
+    */
 }
 
 
@@ -93,7 +97,7 @@ K3b::AbstractCdrtoolsProgram::~AbstractCdrtoolsProgram()
 
 bool K3b::AbstractCdrtoolsProgram::usingCdrkit( const ExternalBin& bin ) const
 {
-    return QFileInfo( bin.path ).baseName() == d->cdrkitAlt;
+    return QFileInfo( bin.path() ).baseName() == d->cdrkitAlt;
 }
 
 
@@ -112,21 +116,21 @@ bool K3b::AbstractCdrtoolsProgram::usingCdrkit( const ExternalBin& bin ) const
 static QString& debianWeirdnessHack( QString& path )
 {
     if( QFile::exists( path + ".mmap" ) ) {
-        kDebug() << "checking for Debian cdrtools wrapper script.";
+        qDebug() << "checking for Debian cdrtools wrapper script.";
         if( QFileInfo( path ).size() < 1024 ) {
-            kDebug() << "Debian Wrapper script size fits. Checking file.";
+            qDebug() << "Debian Wrapper script size fits. Checking file.";
             QFile f( path );
             f.open( QIODevice::ReadOnly );
             QString s = QTextStream( &f ).readAll();
             if( s.contains( "cdrecord.mmap" ) && s.contains( "cdrecord.shm" ) ) {
-                kDebug() << "Found Debian Wrapper script.";
+                qDebug() << "Found Debian Wrapper script.";
                 QString ext;
                 if( K3b::kernelVersion().versionString().left(3) > "2.2" )
                     ext = ".mmap";
                 else
                     ext = ".shm";
 
-                kDebug() << "Using crtools" << ext;
+                qDebug() << "Using crtools" << ext;
 
                 path += ext;
             }
@@ -182,9 +186,9 @@ void K3b::CdrecordProgram::parseFeatures( const QString& output, ExternalBin& bi
     if( usingCdrkit( bin ) )
         bin.addFeature( "wodim" );
 
-    if( bin.version.suffix().endsWith( "-dvd" ) ) {
+    if( bin.version().suffix().endsWith( "-dvd" ) ) {
         bin.addFeature( "dvd-patch" );
-        bin.version = QString(bin.version.versionString()).remove("-dvd");
+        bin.setVersion( QString(bin.version().versionString()).remove("-dvd") );
     }
 
     if( output.contains( "gracetime" ) )
@@ -198,7 +202,7 @@ void K3b::CdrecordProgram::parseFeatures( const QString& output, ExternalBin& bi
     if( output.contains( "-tao" ) )
         bin.addFeature( "tao" );
     if( output.contains( "cuefile=" ) &&
-        ( usingCdrkit( bin ) || bin.version > K3b::Version( 2, 1, -1, "a14") ) ) // cuefile handling was still buggy in a14
+        ( usingCdrkit( bin ) || bin.version() > K3b::Version( 2, 1, -1, "a14") ) ) // cuefile handling was still buggy in a14
         bin.addFeature( "cuefile" );
 
     // new mode 2 options since cdrecord 2.01a12
@@ -207,31 +211,31 @@ void K3b::CdrecordProgram::parseFeatures( const QString& output, ExternalBin& bi
     // two checks)
     // and the version check does not handle versions like 2.01-dvd properly
     if( output.contains( "-xamix" ) ||
-        bin.version >= K3b::Version( 2, 1, -1, "a12" ) ||
+        bin.version() >= K3b::Version( 2, 1, -1, "a12" ) ||
         usingCdrkit( bin ) )
         bin.addFeature( "xamix" );
 
-    if( bin.version < K3b::Version( 2, 0 ) && !usingCdrkit( bin ) )
+    if( bin.version() < K3b::Version( 2, 0 ) && !usingCdrkit( bin ) )
         bin.addFeature( "outdated" );
 
     // FIXME: are these version correct?
-    if( bin.version >= K3b::Version("1.11a38") || usingCdrkit( bin ) )
+    if( bin.version() >= K3b::Version("1.11a38") || usingCdrkit( bin ) )
         bin.addFeature( "plain-atapi" );
-    if( bin.version > K3b::Version("1.11a17") || usingCdrkit( bin ) )
+    if( bin.version() > K3b::Version("1.11a17") || usingCdrkit( bin ) )
         bin.addFeature( "hacked-atapi" );
 
-    if( bin.version >= K3b::Version( 2, 1, 1, "a02" ) || usingCdrkit( bin ) )
+    if( bin.version() >= K3b::Version( 2, 1, 1, "a02" ) || usingCdrkit( bin ) )
         bin.addFeature( "short-track-raw" );
 
-    if( bin.version >= K3b::Version( 2, 1, -1, "a13" ) || usingCdrkit( bin ) )
+    if( bin.version() >= K3b::Version( 2, 1, -1, "a13" ) || usingCdrkit( bin ) )
         bin.addFeature( "audio-stdin" );
 
-    if( bin.version >= K3b::Version( "1.11a02" ) || usingCdrkit( bin ) )
+    if( bin.version() >= K3b::Version( "1.11a02" ) || usingCdrkit( bin ) )
         bin.addFeature( "burnfree" );
     else
         bin.addFeature( "burnproof" );
 
-    if ( bin.version >= K3b::Version( 2, 1, 1, "a29" ) && !usingCdrkit( bin ) )
+    if ( bin.version() >= K3b::Version( 2, 1, 1, "a29" ) && !usingCdrkit( bin ) )
         bin.addFeature( "blu-ray" );
 
     // FIXME: when did cdrecord introduce free dvd support?
@@ -262,16 +266,16 @@ void K3b::MkisofsProgram::parseFeatures( const QString& output, ExternalBin& bin
     if( output.contains( "-sectype" ) )
         bin.addFeature( "sectype" );
 
-    if( bin.version < K3b::Version( 1, 14) && !usingCdrkit( bin ) )
+    if( bin.version() < K3b::Version( 1, 14) && !usingCdrkit( bin ) )
         bin.addFeature( "outdated" );
 
-    if( bin.version >= K3b::Version( 1, 15, -1, "a40" ) || usingCdrkit( bin ) )
+    if( bin.version() >= K3b::Version( 1, 15, -1, "a40" ) || usingCdrkit( bin ) )
         bin.addFeature( "backslashed_filenames" );
 
-    if ( usingCdrkit( bin ) && bin.version >= K3b::Version( 1, 1, 4 ) )
+    if ( usingCdrkit( bin ) && bin.version() >= K3b::Version( 1, 1, 4 ) )
         bin.addFeature( "no-4gb-limit" );
 
-    if ( !usingCdrkit( bin ) && bin.version >= K3b::Version( 2, 1, 1, "a32" ) )
+    if ( !usingCdrkit( bin ) && bin.version() >= K3b::Version( 2, 1, 1, "a32" ) )
         bin.addFeature( "no-4gb-limit" );
 }
 
@@ -291,9 +295,9 @@ void K3b::ReadcdProgram::parseFeatures( const QString& output, ExternalBin& bin
         bin.addFeature( "clone" );
 
     // FIXME: are these version correct?
-    if( bin.version >= K3b::Version("1.11a38") || usingCdrkit( bin ) )
+    if( bin.version() >= K3b::Version("1.11a38") || usingCdrkit( bin ) )
         bin.addFeature( "plain-atapi" );
-    if( bin.version > K3b::Version("1.11a17") || usingCdrkit( bin ) )
+    if( bin.version() > K3b::Version("1.11a17") || usingCdrkit( bin ) )
         bin.addFeature( "hacked-atapi" );
 }
 
@@ -338,7 +342,7 @@ bool K3b::CdrdaoProgram::scanFeatures( ExternalBin& bin ) const
     // probe features
     KProcess fp;
     fp.setOutputChannelMode( KProcess::MergedChannels );
-    fp << bin.path << "write" << "-h";
+    fp << bin.path() << "write" << "-h";
 
     if( fp.execute() >= 0 ) {
         QByteArray out = fp.readAll();
@@ -352,20 +356,20 @@ bool K3b::CdrdaoProgram::scanFeatures( ExternalBin& bin ) const
 
         // SuSE 9.0 ships with a patched cdrdao 1.1.7 which contains an updated libschily
         // Gentoo ships with a patched cdrdao 1.1.7 which contains scglib support
-        if( bin.version > K3b::Version( 1, 1, 7 ) ||
-            bin.version == K3b::Version( 1, 1, 7, "-gentoo" ) ||
-            bin.version == K3b::Version( 1, 1, 7, "-suse" ) ) {
+        if( bin.version() > K3b::Version( 1, 1, 7 ) ||
+            bin.version() == K3b::Version( 1, 1, 7, "-gentoo" ) ||
+            bin.version() == K3b::Version( 1, 1, 7, "-suse" ) ) {
             //    bin.addFeature( "plain-atapi" );
             bin.addFeature( "hacked-atapi" );
         }
 
-        if( bin.version >= K3b::Version( 1, 1, 8 ) )
+        if( bin.version() >= K3b::Version( 1, 1, 8 ) )
             bin.addFeature( "plain-atapi" );
 
         return SimpleExternalProgram::scanFeatures( bin );
     }
     else {
-        kDebug() << "could not start " << bin.path;
+        qDebug() << "could not start " << bin.path();
         return false;
     }
 }
@@ -388,7 +392,7 @@ bool K3b::TranscodeProgram::scanFeatures( ExternalBin& bin ) const
     //
     // Check features
     //
-    QString modInfoBin = buildProgramPath( QFileInfo( bin.path ).absolutePath(), QLatin1String( "tcmodinfo" ) );
+    QString modInfoBin = buildProgramPath( QFileInfo( bin.path() ).absolutePath(), QLatin1String( "tcmodinfo" ) );
     Process modp;
     modp.setOutputChannelMode( KProcess::MergedChannels );
     modp << modInfoBin << "-p";
@@ -408,7 +412,7 @@ bool K3b::TranscodeProgram::scanFeatures( ExternalBin& bin ) const
         return true;
     }
     else {
-        kDebug() << "Failed to start" << modp.program();
+        qDebug() << "Failed to start" << modp.program();
         return false;
     }
 }
@@ -441,21 +445,21 @@ K3b::GrowisofsProgram::GrowisofsProgram()
 bool K3b::GrowisofsProgram::scanFeatures( ExternalBin& bin ) const
 {
     // fixed Copyright:
-    bin.copyright = "Andy Polyakov <appro@fy.chalmers.se>";
+    bin.setCopyright( "Andy Polyakov <appro@fy.chalmers.se>" );
 
-    if ( bin.version >= K3b::Version( 5, 20 ) )
+    if ( bin.version() >= K3b::Version( 5, 20 ) )
         bin.addFeature( "dual-layer" );
 
-    if ( bin.version > K3b::Version( 5, 17 ) )
+    if ( bin.version() > K3b::Version( 5, 17 ) )
         bin.addFeature( "tracksize" );
 
-    if ( bin.version >= K3b::Version( 5, 15 ) )
+    if ( bin.version() >= K3b::Version( 5, 15 ) )
         bin.addFeature( "daosize" );
 
-    if ( bin.version >= K3b::Version( 6, 0 ) )
+    if ( bin.version() >= K3b::Version( 6, 0 ) )
         bin.addFeature( "buffer" );
 
-    if ( bin.version >= K3b::Version( 7, 0 ) )
+    if ( bin.version() >= K3b::Version( 7, 0 ) )
         bin.addFeature( "blu-ray" );
 
     return SimpleExternalProgram::scanFeatures( bin );
@@ -472,7 +476,7 @@ K3b::Version K3b::DvdformatProgram::parseVersion( const QString& output, const E
 {
     QString version;
     // extract fields
-    QStringList outputList = output.split( " " );
+    QStringList outputList = output.split( ' ' );
 
     for (int i = 0; i < outputList.size(); ++i) {
         if ( outputList.at( i ) == "version" ) {
@@ -492,7 +496,7 @@ QString K3b::DvdformatProgram::parseCopyright( const QString& output, const Exte
 {
     QString copyright = "Andy Polyakov ";
     // extract fields
-    QStringList outputList = output.split( " " );
+    QStringList outputList = output.split( ' ' );
 
     for (int i = 0; i < outputList.size(); ++i) {
         if ( outputList.at( i ) == "by" ) {
@@ -530,3 +534,64 @@ QString K3b::DvdBooktypeProgram::parseCopyright( const QString& /*output*/, cons
     // fixed Copyright:
     return QLatin1String( "Andy Polyakov <appro@fy.chalmers.se>" );
 }
+
+K3b::CdrskinProgram::CdrskinProgram()
+    : K3b::SimpleExternalProgram(QLatin1String("cdrskin"))
+{
+}
+
+bool K3b::CdrskinProgram::scanFeatures(ExternalBin& bin) const
+{
+    KProcess fp;
+    fp.setOutputChannelMode(KProcess::MergedChannels);
+    fp << bin.path() << "-help";
+
+    if (fp.execute() >= 0) {
+        QByteArray output = fp.readAll();
+
+        if (output.contains("gracetime"))
+            bin.addFeature("gracetime");
+        if (output.contains("-overburn"))
+            bin.addFeature("overburn");
+        if (output.contains("-text"))
+            bin.addFeature("cdtext");
+        if (output.contains("-clone"))
+            bin.addFeature("clone");
+        if (output.contains("-tao"))
+            bin.addFeature("tao");
+    }
+
+#ifdef K3B_DEBUG
+    qDebug() << "DEBUG:" << __PRETTY_FUNCTION__ << bin.version(); // 1.4.6 for example
+#endif
+    // TODO: cdrskin -help | grep XXX
+    // Hello Thomas, please help me: the other version number dependent features 
+    // need to be checked what they mean and whether cdrskin supports them.
+    if (bin.version().suffix().endsWith("-dvd")) {
+        bin.addFeature("dvd-patch");
+        bin.setVersion(QString(bin.version().versionString()).remove("-dvd"));
+    }
+
+    // TODO: find . -name "*.cpp" | xargs grep plain-atapi
+    // In src/k3bsystemproblemdialog.cpp there is Check for we have atapi support 
+    // in some way in the kernel
+    bin.addFeature("plain-atapi");
+    // The same story
+    bin.addFeature("hacked-atapi");
+
+    bin.addFeature("burnfree");
+
+    if (bin.version() >= K3b::Version(0, 6, 2)) {
+#ifdef K3B_DEBUG
+        qDebug() << "DEBUG:" << __PRETTY_FUNCTION__ << "Blu-ray support was complete in cdrskin-0.6.2, 20 Feb 2009";
+#endif
+        bin.addFeature("blu-ray");
+    }
+
+    bin.addFeature("dvd");
+#ifdef K3B_DEBUG
+    qDebug() << "DEBUG:" << __PRETTY_FUNCTION__ << bin.features();
+#endif
+
+    return SimpleExternalProgram::scanFeatures(bin);
+}
