@@ -2,9 +2,10 @@
 *
 * Copyright (C) 2003 Christian Kvasny <chris@k3b.org>
 * Copyright (C) 2009 Sebastian Trueg <trueg@k3b.org>
+* Copyright (C) 2010 Michal Malek <michalm@jabster.pl>
 *
 * This file is part of the K3b project.
-* Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
+* Copyright (C) 1998-2010 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -14,22 +15,20 @@
 */
 
 #include "k3bvideocdinfo.h"
-
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qtimer.h>
-#include <qdom.h>
-
-#include <klocale.h>
-#include <kconfig.h>
-#include <kdebug.h>
-
+#include "k3bcore.h"
 #include "k3bprocess.h"
 #include "k3bexternalbinmanager.h"
 
+#include <KConfigCore/KConfig>
+#include <KI18n/KLocalizedString>
+
+#include <QtCore/QDebug>
+#include <QtXml/QDomDocument>
+#include <QtXml/QDomElement>
+
 
 K3b::VideoCdInfo::VideoCdInfo( QObject* parent )
-        : QObject( parent )
+    : QObject( parent )
 {
     m_process = 0L;
     m_isXml = false;
@@ -52,7 +51,7 @@ void K3b::VideoCdInfo::cancelAll()
 void K3b::VideoCdInfo::info( const QString& device )
 {
     if ( !k3bcore ->externalBinManager() ->foundBin( "vcdxrip" ) ) {
-        kDebug() << "(K3b::VideoCdInfo::info) could not find vcdxrip executable";
+        qDebug() << "(K3b::VideoCdInfo::info) could not find vcdxrip executable";
         emit infoFinished( false );
         return ;
     }
@@ -70,11 +69,11 @@ void K3b::VideoCdInfo::info( const QString& device )
              this, SLOT(slotParseOutput(QString)) );
     connect( m_process, SIGNAL(stdoutLine(QString)),
              this, SLOT(slotParseOutput(QString)) );
-    connect( m_process, SIGNAL( finished( int, QProcess::ExitStatus ) ),
-             this, SLOT( slotInfoFinished( int, QProcess::ExitStatus ) ) );
+    connect( m_process, SIGNAL(finished(int,QProcess::ExitStatus)),
+             this, SLOT(slotInfoFinished(int,QProcess::ExitStatus)) );
 
     if ( !m_process->start( KProcess::SeparateChannels ) ) {
-        kDebug() << "(K3b::VideoCdInfo::info) could not start vcdxrip";
+        qDebug() << "(K3b::VideoCdInfo::info) could not start vcdxrip";
         cancelAll();
         emit infoFinished( false );
     }
@@ -88,7 +87,7 @@ void K3b::VideoCdInfo::slotParseOutput( const QString& inp )
     if ( m_isXml )
         m_xmlData += inp;
     else
-        kDebug() << "(K3b::VideoCdInfo::slotParseOutput) " << inp;
+        qDebug() << "(K3b::VideoCdInfo::slotParseOutput) " << inp;
 
     if ( inp.contains( "</videocd>" ) )
         m_isXml = false;
@@ -103,16 +102,19 @@ void K3b::VideoCdInfo::slotInfoFinished( int exitCode, QProcess::ExitStatus exit
                 break;
             default:
                 cancelAll();
+                qDebug() << "vcdxrip finished with exit code" << exitCode;
                 emit infoFinished( false );
                 return ;
         }
     } else {
         cancelAll();
+        qDebug() << "vcdxrip crashed!";
         emit infoFinished( false );
         return ;
     }
 
     if ( m_xmlData.isEmpty() ) {
+        qDebug() << "XML data empty!";
         emit infoFinished( false );
         return ;
     }
@@ -150,7 +152,6 @@ void K3b::VideoCdInfo::parseXmlData()
         } else if ( tagName == "sequence-items" ) {
             for ( QDomNode snode = node.firstChild(); !snode.isNull(); snode = snode.nextSibling() ) {
                 QDomElement sel = snode.toElement();
-                QString seqElement = sel.tagName().toLower();
                 m_Result.addEntry( K3b::VideoCdInfoResultEntry(
                                        sel.attribute( "src" ),
                                        sel.attribute( "id" ) ),
@@ -160,7 +161,6 @@ void K3b::VideoCdInfo::parseXmlData()
         } else if ( tagName == "segment-items" ) {
             for ( QDomNode snode = node.firstChild(); !snode.isNull(); snode = snode.nextSibling() ) {
                 QDomElement sel = snode.toElement();
-                QString seqElement = sel.tagName().toLower();
                 m_Result.addEntry( K3b::VideoCdInfoResultEntry(
                                        sel.attribute( "src" ),
                                        sel.attribute( "id" ) ),
@@ -168,7 +168,7 @@ void K3b::VideoCdInfo::parseXmlData()
                                  );
             }
         } else {
-            kDebug() << QString( "(K3b::VideoCdInfo::parseXmlData) tagName '%1' not used" ).arg( tagName );
+            qDebug() << QString( "(K3b::VideoCdInfo::parseXmlData) tagName '%1' not used" ).arg( tagName );
         }
     }
 }
@@ -194,7 +194,7 @@ const K3b::VideoCdInfoResultEntry& K3b::VideoCdInfoResult::entry( int number, in
                 return m_emptyEntry;
             return m_sequenceEntry[ number ];
         default:
-            kDebug() << "(K3b::VideoCdInfoResult::entry) not supported entrytype.";
+            qDebug() << "(K3b::VideoCdInfoResult::entry) not supported entrytype.";
     }
 
     return m_emptyEntry;
@@ -215,7 +215,7 @@ void K3b::VideoCdInfoResult::addEntry( const K3b::VideoCdInfoResultEntry& entry,
             m_sequenceEntry.append( entry );
             break;
         default:
-            kDebug() << "(K3b::VideoCdInfoResult::addEntry) not supported entrytype.";
+            qDebug() << "(K3b::VideoCdInfoResult::addEntry) not supported entrytype.";
     }
 }
 
@@ -229,10 +229,10 @@ int K3b::VideoCdInfoResult::foundEntries( int type ) const
         case K3b::VideoCdInfoResult::SEQUENCE:
             return m_sequenceEntry.count();
         default:
-            kDebug() << "(K3b::VideoCdInfoResult::addEntry) not supported entrytype.";
+            qDebug() << "(K3b::VideoCdInfoResult::addEntry) not supported entrytype.";
     }
     return 0;
 }
 
-#include "k3bvideocdinfo.moc"
+
 
